==> gorilla-notes-0.4.0-20200912.222428-2.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$DailyMotion.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$DailyMotion=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _slicedToArray(arr,i){var JSCompiler_temp=Array.isArray(arr)?arr:void 0;if(!JSCompiler_temp)if("undefined"!==typeof Symbol&&Symbol.iterator in Object(arr)){JSCompiler_temp=
[];var _n=!0,_d=!1,_e=void 0;try{for(var _i=arr[Symbol.iterator](),_s;!(_n=(_s=_i.next()).done)&&(JSCompiler_temp.push(_s.value),!i||JSCompiler_temp.length!==i);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=_i["return"])_i["return"]()}finally{if(_d)throw _e;}}}else JSCompiler_temp=void 0;if(!(_i=JSCompiler_temp))a:{if(arr){if("string"===typeof arr){_i=_arrayLikeToArray(arr,i);break a}_i=Object.prototype.toString.call(arr).slice(8,-1);"Object"===_i&&arr.constructor&&(_i=arr.constructor.name);
if("Map"===_i||"Set"===_i){_i=Array.from(_i);break a}if("Arguments"===_i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(_i)){_i=_arrayLikeToArray(arr,i);break a}}_i=void 0}if(!(arr=_i))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");return arr}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}
function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=
_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===
typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");
subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}
Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.DailyMotion=void 0;var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?
Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/^(?:(?:https?):)?(?:\/\/)?(?:www\.)?(?:(?:dailymotion\.com(?:\/embed)?\/video)|dai\.ly)\/([a-zA-Z0-9]+)(?:_[\w_-]+)?$/;
require=function(_Component){function DailyMotion(){if(!(this instanceof DailyMotion))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"onDurationChange",function(){var duration=_this.getDuration();_this.props.onDuration(duration)});
_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("setMuted",!0)});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("setMuted",!1)});_defineProperty(_assertThisInitialized(_this),"ref",function(container){_this.container=container});return _this}_inherits(DailyMotion,_Component);var _super=_createSuper(DailyMotion);_createClass(DailyMotion,[{key:"load",value:function(url){var _this2=this,_this$props=this.props,controls=_this$props.controls,
config=_this$props.config,onError=_this$props.onError;_this$props=_this$props.playing;var _url$match=url.match(MATCH_URL),id=_slicedToArray(_url$match,2)[1];this.player?this.player.load(id,{start:(0,_utils.parseStartTime)(url),autoplay:_this$props}):(0,_utils.getSDK)("https://api.dmcdn.net/all.js","DM","dmAsyncInit",function(DM){return DM.player}).then(function(DM){_this2.container&&(_this2.player=new DM.player(_this2.container,{width:"100%",height:"100%",video:id,params:_objectSpread({controls,autoplay:_this2.props.playing,
mute:_this2.props.muted,start:(0,_utils.parseStartTime)(url),origin:window.location.origin},config.dailymotion.params),events:{apiready:_this2.props.onReady,seeked:function(){return _this2.props.onSeek(_this2.player.currentTime)},video_end:_this2.props.onEnded,durationchange:_this2.onDurationChange,pause:_this2.props.onPause,playing:_this2.props.onPlay,waiting:_this2.props.onBuffer,error:function(event){return onError(event)}}}))},onError)}},{key:"play",value:function(){this.callPlayer("play")}},
{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){}},{key:"seekTo",value:function(seconds){this.callPlayer("seek",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},{key:"getDuration",value:function(){return this.player.duration||null}},{key:"getCurrentTime",value:function(){return this.player.currentTime}},{key:"getSecondsLoaded",value:function(){return this.player.bufferedTime}},{key:"render",value:function(){return _react["default"].createElement("div",
{style:{width:"100%",height:"100%",display:this.props.display}},_react["default"].createElement("div",{ref:this.ref}))}}]);return DailyMotion}(_react.Component);exports.DailyMotion=require;_defineProperty(require,"displayName","DailyMotion");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$DailyMotion.js.map

==> gorilla-notes-0.5.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$DailyMotion.js <==
shadow$provide.module$node_modules$react_player$lib$players$DailyMotion=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _slicedToArray(arr,i){var JSCompiler_temp=Array.isArray(arr)?arr:void 0;if(!JSCompiler_temp)if("undefined"!==typeof Symbol&&Symbol.iterator in Object(arr)){JSCompiler_temp=
[];var _n=!0,_d=!1,_e=void 0;try{for(var _i=arr[Symbol.iterator](),_s;!(_n=(_s=_i.next()).done)&&(JSCompiler_temp.push(_s.value),!i||JSCompiler_temp.length!==i);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=_i["return"])_i["return"]()}finally{if(_d)throw _e;}}}else JSCompiler_temp=void 0;if(!(_i=JSCompiler_temp))a:{if(arr){if("string"===typeof arr){_i=_arrayLikeToArray(arr,i);break a}_i=Object.prototype.toString.call(arr).slice(8,-1);"Object"===_i&&arr.constructor&&(_i=arr.constructor.name);
if("Map"===_i||"Set"===_i){_i=Array.from(_i);break a}if("Arguments"===_i||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(_i)){_i=_arrayLikeToArray(arr,i);break a}}_i=void 0}if(!(arr=_i))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");return arr}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}
function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=
_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===
typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");
subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}
Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.DailyMotion=void 0;var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?
Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/^(?:(?:https?):)?(?:\/\/)?(?:www\.)?(?:(?:dailymotion\.com(?:\/embed)?\/video)|dai\.ly)\/([a-zA-Z0-9]+)(?:_[\w_-]+)?$/;
require=function(_Component){function DailyMotion(){if(!(this instanceof DailyMotion))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"onDurationChange",function(){var duration=_this.getDuration();_this.props.onDuration(duration)});
_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("setMuted",!0)});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("setMuted",!1)});_defineProperty(_assertThisInitialized(_this),"ref",function(container){_this.container=container});return _this}_inherits(DailyMotion,_Component);var _super=_createSuper(DailyMotion);_createClass(DailyMotion,[{key:"load",value:function(url){var _this2=this,_this$props=this.props,controls=_this$props.controls,
config=_this$props.config,onError=_this$props.onError;_this$props=_this$props.playing;var _url$match=url.match(MATCH_URL),id=_slicedToArray(_url$match,2)[1];this.player?this.player.load(id,{start:(0,_utils.parseStartTime)(url),autoplay:_this$props}):(0,_utils.getSDK)("https://api.dmcdn.net/all.js","DM","dmAsyncInit",function(DM){return DM.player}).then(function(DM){_this2.container&&(_this2.player=new DM.player(_this2.container,{width:"100%",height:"100%",video:id,params:_objectSpread({controls:controls,
autoplay:_this2.props.playing,mute:_this2.props.muted,start:(0,_utils.parseStartTime)(url),origin:window.location.origin},config.dailymotion.params),events:{apiready:_this2.props.onReady,seeked:function(){return _this2.props.onSeek(_this2.player.currentTime)},video_end:_this2.props.onEnded,durationchange:_this2.onDurationChange,pause:_this2.props.onPause,playing:_this2.props.onPlay,waiting:_this2.props.onBuffer,error:function(event){return onError(event)}}}))},onError)}},{key:"play",value:function(){this.callPlayer("play")}},
{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){}},{key:"seekTo",value:function(seconds){this.callPlayer("seek",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},{key:"getDuration",value:function(){return this.player.duration||null}},{key:"getCurrentTime",value:function(){return this.player.currentTime}},{key:"getSecondsLoaded",value:function(){return this.player.bufferedTime}},{key:"render",value:function(){return _react["default"].createElement("div",
{style:{width:"100%",height:"100%",display:this.props.display}},_react["default"].createElement("div",{ref:this.ref}))}}]);return DailyMotion}(_react.Component);exports.DailyMotion=require;_defineProperty(require,"displayName","DailyMotion");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$DailyMotion.js.map
